# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.
import unittest
import trytond.tests.test_tryton
from trytond.tests.test_tryton import ModuleTestCase

from trytond.modules.company.tests import CompanyTestMixin


class ProjectPlanTestCase(CompanyTestMixin, ModuleTestCase):
    'Test ProjectPlan module'
    module = 'project_plan'


def suite():
    suite = trytond.tests.test_tryton.suite()
    suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
        ProjectPlanTestCase))
    return suite
